@@ -152,7 +152,7 @@ public class HostConfiguration {
         loadMinimumVersions(configurationService);
         threadingType = ThreadingType.from(ConfigurationHelper.getString(configurationService, THREADING_TYPE, ThreadingType.THREADREFERENCES.toString()));
         numMailsPerFolder = ConfigurationHelper.getNumberString(configurationService, MAILS_PER_FOLDER, "10000");
-        returnNonPrimaryAccounts = ConfigurationHelper.getBoolean(configurationService, RETURN_NON_PRIMARY_ACCOUNTS, false);
+        returnNonPrimaryAccounts = ConfigurationHelper.getBoolean(configurationService, RETURN_NON_PRIMARY_ACCOUNTS, true);
         includeNonPrivateFolders = ConfigurationHelper.getBoolean(configurationService, INCLUDE_NON_PRIVATE_FOLDERS, false);
         mailTeasersEnabled = ConfigurationHelper.getBoolean(configurationService, MAIL_TEASERS_ENABLED, true);
         mailTeasersDefaultLength = ConfigurationHelper.getNumber(configurationService, MAIL_TEASERS_DEFAULT_LENGTH, 300);
