@@ -81,10 +81,13 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
 
     private static final int TYPE_PUBLIC = 2;
 
+    private String rootFolderId;
+
     private String language;
 
-    public AllFoldersConnector(RequestConfiguration configuration, SessionData sessionData, String language) {
+    public AllFoldersConnector(RequestConfiguration configuration, SessionData sessionData, String rootFolderId, String language) {
         super(configuration, sessionData, "folders", FoldersResponseMto.class);
+        this.rootFolderId = rootFolderId;
         this.language = language;
     }
 
@@ -96,6 +99,9 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         builder.addParameter("action", "allVisible");
         builder.addParameter("content_type", "mail");
         builder.addParameter("columns", "1,20,300,302,316");
+        if (!StringUtils.isEmpty(rootFolderId)) {
+            builder.addParameter("root", rootFolderId);
+        }
         if (!StringUtils.isEmpty(language)) {
             builder.addParameter("language", language);
         }
