@@ -49,6 +49,7 @@
 
 package com.openexchange.mobile.api.facade.endpoints.responses.ctos;
 
+import java.util.Iterator;
 import java.util.List;
 
 import com.fasterxml.jackson.annotation.JsonInclude;
@@ -72,7 +73,7 @@ public class MailCto {
         }
     };
 
-    private static final MapFunction<Attachment, AttachmentCto> attachmentMapFunction = new MapFunction<Attachment, AttachmentCto>() {
+    private static final MapFunction<Attachment, AttachmentCto> partMapFunction = new MapFunction<Attachment, AttachmentCto>() {
         @Override
         public AttachmentCto map(Attachment attachment) {
             return new AttachmentCto(attachment);
@@ -142,10 +143,10 @@ public class MailCto {
         contentType = mail.getContentType();
         size = mail.getSize();
         priority = getPriorityOrNull(mail.getPriority());
-        List<AttachmentCto> attachments = ListUtil.map(mail.getAttachments(), attachmentMapFunction);
+        List<AttachmentCto> attachments = ListUtil.map(mail.getParts(), partMapFunction);
         body = getBodyOrNull(attachments);
         bodyType = getBodyTypeOrNull(attachments);
-        realAttachment = mail.getRealAttachment();
+        realAttachment = mail.getHasAttachments();
         this.attachments = getAttachmentListWithoutBodyOrNull(attachments);
     }
 
@@ -154,20 +155,38 @@ public class MailCto {
     }
 
     private String getBodyOrNull(List<AttachmentCto> attachments) {
-        return !ListUtil.isEmpty(attachments) ? attachments.get(0).getContent() : null;
+        AttachmentCto part = findContentPart(attachments);
+        return part != null ? part.getContent() : null;
     }
 
     private String getBodyTypeOrNull(List<AttachmentCto> attachments) {
-        return !ListUtil.isEmpty(attachments) ? attachments.get(0).getContentType() : null;
+        AttachmentCto part = findContentPart(attachments);
+        return part != null ? part.getContentType() : null;
+    }
+
+    private AttachmentCto findContentPart(List<AttachmentCto> parts) {
+        if (parts == null) {
+            return null;
+        }
+        for (AttachmentCto part : parts) {
+            if (!"attachment".equals(part.getDisposition())) {
+                return part;
+            }
+        }
+        return null;
     }
 
     private List<AttachmentCto> getAttachmentListWithoutBodyOrNull(List<AttachmentCto> attachments) {
-        if (!ListUtil.isEmpty(attachments)) {
-            attachments.remove(0);
-            return attachments;
-        } else {
+        if (ListUtil.isEmpty(attachments)) {
             return null;
         }
+        for (Iterator<AttachmentCto> it = attachments.iterator(); it.hasNext(); ) {
+            AttachmentCto attachment = it.next();
+            if (!"attachment".equals(attachment.getDisposition())) {
+                it.remove();
+            }
+        }
+        return attachments;
     }
 
 }
