@@ -56,6 +56,7 @@ import java.util.List;
 import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactory;
 import com.openexchange.mobile.api.facade.connectors.ConnectorFactoryFactory;
+import com.openexchange.mobile.api.facade.connectors.JsLob;
 import com.openexchange.mobile.api.facade.connectors.impl.AccountsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.AllFoldersConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ClearFolderConnector;
@@ -63,11 +64,13 @@ import com.openexchange.mobile.api.facade.connectors.impl.ConfigConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.CreateFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ExamineMultipleFoldersConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.GetJsLobConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.UserConnector;
 import com.openexchange.mobile.api.facade.connectors.responses.ArrayDataResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.ConfigResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.ExamineResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.FoldersResponseMto;
+import com.openexchange.mobile.api.facade.connectors.responses.RawResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.StringResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.UserResponseMto;
 import com.openexchange.mobile.api.facade.connectors.responses.mtos.AccountMto;
@@ -79,6 +82,7 @@ import com.openexchange.mobile.api.facade.models.Config;
 import com.openexchange.mobile.api.facade.models.CreatedFolder;
 import com.openexchange.mobile.api.facade.models.ExamineResult;
 import com.openexchange.mobile.api.facade.models.Folder;
+import com.openexchange.mobile.api.facade.utils.JsonUtil;
 import com.openexchange.mobile.api.facade.utils.ListUtil;
 import com.openexchange.mobile.api.facade.utils.MapFunction;
 
@@ -119,16 +123,32 @@ public class FoldersService {
 
             @Override
             public Account map(AccountMto accountMto) {
-                List<Folder> folders = retrieveFolders(connectorFactory, sessionData, accountMto, language);
-                examineFolders(connectorFactory, sessionData, folders);
-                Account account = new Account(accountMto, userMto, folders);
-                adjustFolderParents(account, isNamespaceSet);
-                return account;
+                return mapAccount(connectorFactory, sessionData, accountMto, userMto, language, isNamespaceSet);
             }
 
         });
     }
 
+    private Account mapAccount(ConnectorFactory connectorFactory, SessionData sessionData, AccountMto accountMto, UserMto userMto, String language, boolean isNamespaceSet) {
+        List<Folder> folders = retrieveFolders(connectorFactory, sessionData, accountMto, language);
+        examineFolders(connectorFactory, sessionData, folders);
+        String defaultSendAddress;
+        if (accountMto.isPrimaryAccount()) {
+            defaultSendAddress = retrieveDefaultSendAddress(connectorFactory, sessionData);
+        } else {
+            defaultSendAddress = null;
+        }
+        Account account = new Account(accountMto, userMto, defaultSendAddress, folders);
+        adjustFolderParents(account, isNamespaceSet);
+        return account;
+    }
+
+    private String retrieveDefaultSendAddress(ConnectorFactory connectorFactory, SessionData sessionData) {
+        GetJsLobConnector jsLobConnector = connectorFactory.getGetJsLobConnector(sessionData, JsLob.MAIL);
+        RawResponseMto response = jsLobConnector.execute();
+        return JsonUtil.getString(GetJsLobConnector.map(response), "defaultSendAddress");
+    }
+
     private Config retrieveConfiguration(ConnectorFactory connectorFactory, SessionData sessionData) {
         ConfigConnector configConnector = connectorFactory.getConfigConnector(sessionData);
         ConfigResponseMto response = configConnector.execute();
