@@ -160,7 +160,7 @@ public class MailsService {
         Mail mail = GetMailConnector.map(responseBody.getData());
         boolean mailTeasersEnabled = sessionData.getConfiguration().isMailTeasersEnabled();
         mail = MailTransformations.apply(mail, mailTeasersEnabled, maximumTeaserLength);
-        AttachmentUtil.initializeDownloadUrls(sessionData.getSession(), folderId, mail);
+        AttachmentUtil.initializeDownloadUrls(folderId, mail);
         return mail;
     }
 
